from imports.src.abstract_react.meta_utils.apis.metadata.metadata import *
image = "/home/op/Documents/python/modules/src/modules/abstract_react/tests/test_image/abstractendeavors.webp"
info = {"thumbnail":image}
base_image_dir = "/home/op/Documents/python/modules/src/modules/abstract_react/tests/test_image/"
base_image_url = "https://thedailydialectics.com/image"
meta_data = get_meta_info(info,base_image_dir=base_image_dir,base_image_url=base_image_url)
input(meta_data)
